angular.module('beamng.apps')
.directive('gasTurbineDebug', [function () {
  return {
    template:`
      <div style="height: 100%; overflow: auto; background-color: rgba(255, 255, 255, 0.9)">
        <table cellpadding="3">
          <tr ng-repeat="m in fixedMeasures">
            <td valign="baseline" align="right">{{ ::m.name }} &nbsp; </td>
            <td valign="baseline" style="font-family: monospace; font-size: 1.2em">{{ m.val.toFixed(2) }} {{ ::m.units }}</td>
          </tr>

          <tr ng-repeat="m in optionalMeasures | filter: valueDefined">
            <td valign="baseline" align="right">{{ ::m.name }} &nbsp; </td>
            <td valign="baseline" style="font-family: monospace; font-size: 1.2em">{{ m.val.toFixed(2) }} {{ ::m.units }}</td>
          </tr>
        </table>
      </div>`,
    replace: true,
    restrict: 'EA',
    scope: true,
    controller: ['$log', '$scope', 'bngApi', 'StreamsManager', function ($log, $scope, bngApi, StreamsManager) {
      var streamsList = ['gasTurbineData'];
      StreamsManager.add(streamsList);
      $scope.$on('$destroy', function () {
        StreamsManager.remove(streamsList);
      });

      var init = function () {
        $scope.$evalAsync(function () {
          $scope.fixedMeasures = [
            { name: 'RPM',         val: NaN, units: 'RPM',       key: 'rpm'},
            { name: 'Thrust',      val: NaN, units: 'N',    key: 'thrust'},
            { name: 'Throttle',    val: NaN, units: '%',    key: 'throttle'},
            { name: 'Mass Flow',   val: NaN, units: 'kg/s',    key: 'massflow'},
			{ name: 'Fuel Flow',   val: NaN, units: 'g/s',    key: 'fuelflow'}
			
          ];

          $scope.optionalMeasures = [
			{ name: 'P0/Pa',     val: undefined, units: 'bar', key: 'p0'},
            { name: 'P1',     val: undefined, units: 'bar', key: 'p1'},
            { name: 'P2',     val: undefined, units: 'bar', key: 'p2'},
            { name: 'P3',     val: undefined, units: 'bar', key: 'p3'},
            { name: 'P4',     val: undefined, units: 'bar', key: 'p4'},
            { name: 'P5',     val: undefined, units: 'bar', key: 'p5'},
            { name: 'T0/Ta',     val: undefined, units: '°K', key: 't0'},
            { name: 'T1',     val: undefined, units: '°K', key: 't1'},
            { name: 'T2',     val: undefined, units: '°K', key: 't2'},
            { name: 'T3',     val: undefined, units: '°K', key: 't3'},
            { name: 'T4',     val: undefined, units: '°K', key: 't4'},
            { name: 'T5',     val: undefined, units: '°K', key: 't5'},
			{ name: 'Tpower',     val: undefined, units: 'kW', key: 'Wturbine'},
			{ name: 'Cpower',     val: undefined, units: 'kW', key: 'Wcompressor'},
			{ name: 'Epower',     val: undefined, units: 'kW', key: 'Wexcess'},
			{ name: 'Specific Thurst',     val: undefined, units: 'N/kg/s', key: 'Tspecific'},
			{ name: 'Ua',     val: undefined, units: 'm/s', key: 'Ua'},
			{ name: 'Uj',     val: undefined, units: 'm/s', key: 'Uj'}
          ];  
        });
      };
      

      $scope.valueDefined = function (x) {
        return x.val !== undefined;
      };

      init();

      $scope.$on('VehicleReset', init);
      $scope.$on('VehicleFocusChanged', init);

      $scope.$on('streamsUpdate', function (event, streams) {
        $scope.$evalAsync(function () {
          if (streams.gasTurbineData) {
            $scope.fixedMeasures.forEach((x) => {
              x.val = streams.gasTurbineData[x.key];
            });

            $scope.optionalMeasures.forEach((x) => {
              x.val = streams.gasTurbineData[x.key];
            }); 
          }
        });
      });

    }]
  };
}]);
